@@ -1,6 +1,7 @@
 r"""Linear mixed model package."""
 
 from ._lmm import LMM
+from ._mt_lmm import MTLMM
 from ._scan import FastScanner
 
-__all__ = ["LMM", "FastScanner"]
+__all__ = ["LMM", "MTLMM", "FastScanner"]
