@@ -8,8 +8,13 @@ from glimix_core.cov import EyeCov, LinearCov, SumCov
 from glimix_core.lik import BinomialProdLik, PoissonProdLik
 from glimix_core.link import LogitLink, LogLink
 from glimix_core.mean import OffsetMean
-from glimix_core.random import (GGPSampler, GPSampler, bernoulli_sample,
-                                binomial_sample, poisson_sample)
+from glimix_core.random import (
+    GGPSampler,
+    GPSampler,
+    bernoulli_sample,
+    binomial_sample,
+    poisson_sample
+)
 
 
 def test_binomial_sampler():
