@@ -52,8 +52,8 @@ def test_util_check_outcome():
         check_outcome((y,), "poisson")
 
     y[0] = 0.5
-    want = (array([0.5, 1., 1., 1., 1.]),)
-    assert_allclose(check_outcome((y,), "poisson"), want)
+    want = array([0.5, 1., 1., 1., 1.])
+    assert_allclose(check_outcome(y, "poisson"), want)
 
     x = ones(4)
 
@@ -63,14 +63,13 @@ def test_util_check_outcome():
     x = ones(5)
 
     with pytest.raises(ValueError):
-        check_outcome((y,), "normal")
+        check_outcome(y, "normal")
 
 
 def test_util_check_poisson_outcome():
     y = ones(5)
     y[0] = 25000 + 1
-    want = (
-        array(
+    want = array(
             [
                 2.50000000e+04,
                 1.00000000e+00,
@@ -78,6 +77,6 @@ def test_util_check_poisson_outcome():
                 1.00000000e+00,
                 1.00000000e+00,
             ]
-        ),
-    )
-    assert_allclose(check_outcome((y,), "poisson"), want)
+        )
+    with pytest.warns(UserWarning):
+        assert_allclose(check_outcome(y, "poisson"), want)
